@@ -87,9 +87,9 @@ class Connector(threading.Thread):
 
         try:
             if target_url is None:
-                if doc_manager is None:
+                if doc_manager is None:  # imported using from... import
                     self.doc_manager = DocManager(unique_key=u_key)
-                else:
+                else:  # imported using load source
                     self.doc_manager = doc_manager.DocManager(unique_key=u_key)
             else:
                 if doc_manager is None:
@@ -105,7 +105,7 @@ class Connector(threading.Thread):
 
         if self.oplog_checkpoint is not None:
             if not os.path.exists(self.oplog_checkpoint):
-                info_str = "MongoConnector: Can't find OplogProgress file!"
+                info_str = "MongoC`onnector: Can't find OplogProgress file!"
                 logging.critical(info_str)
                 self.doc_manager.stop()
                 self.can_run = False
@@ -125,24 +125,28 @@ class Connector(threading.Thread):
                 return None
 
         # write to temp file
-        os.rename(self.oplog_checkpoint, self.oplog_checkpoint + '.backup')
-        dest = open(self.oplog_checkpoint, 'w')
-        source = open(self.oplog_checkpoint + '.backup', 'r')
+        backup_file = self.oplog_checkpoint + '.backup'
+        os.rename(self.oplog_checkpoint, backup_file)
 
         # for each of the threads write to file
-        self.oplog_progress.acquire_lock()
-        try:
-            oplog_dict = self.oplog_progress.get_dict()
-            for oplog, ts in oplog_dict.items():
-                oplog_str = str(oplog)
-                timestamp = util.bson_ts_to_long(ts)
-                json_str = json.dumps([oplog_str, timestamp])
-                dest.write(json_str)
-        finally:
-            self.oplog_progress.release_lock()
-            dest.close()
-            source.close()
-            os.remove(self.oplog_checkpoint + '.backup')
+        with open(self.oplog_checkpoint, 'w') as dest:
+            with self.oplog_progress as oplog_prog:
+
+                oplog_dict = oplog_prog.get_dict()
+                for oplog, ts in oplog_dict.items():
+                    oplog_str = str(oplog)
+                    timestamp = util.bson_ts_to_long(ts)
+                    json_str = json.dumps([oplog_str, timestamp])
+                    try:
+                        dest.write(json_str)
+                    except IOError:
+                        # Basically wipe the file, copy from backup
+                        dest.truncate()
+                        with open(backup_file, 'r') as backup:
+                            shutil.copyfile(backup, dest)
+                        break
+
+        os.remove(self.oplog_checkpoint + '.backup')
 
     def read_oplog_progress(self):
         """Reads oplog progress from file provided by user.
@@ -404,6 +408,8 @@ if __name__ == '__main__':
 
     (options, args) = parser.parse_args()
 
+    if options.doc_manager is None:
+        logger.info('No doc manager specified, using simulator.')
     try:
         if options.ns_set is None:
             ns_set = []
@@ -426,6 +432,10 @@ if __name__ == '__main__':
     if options.password is not None:
         key = options.password
 
+    if key is None and options.admin_name != "__system":
+        logger.error("Admin username specified without password!")
+        sys.exit(1)
+
     ct = Connector(options.main_addr, options.oplog_config, options.url,
                    ns_set, options.u_key, key, options.doc_manager,
                    auth_username=options.admin_name)
